Object.defineProperty(exports, Symbol.toStringTag, { value: 'Module' });

const fs = require('fs');
const path = require('path');

/**
 * Supported @sveltejs/adapters-[adapter] SvelteKit adapters
 */

/**
 * Tries to detect the used adapter for SvelteKit by looking at the dependencies.
 * returns the name of the adapter or 'other' if no supported adapter was found.
 */
async function detectAdapter(debug) {
  const pkgJson = await loadPackageJson();

  const allDependencies = pkgJson ? { ...pkgJson.dependencies, ...pkgJson.devDependencies } : {};

  let adapter = 'other';
  if (allDependencies['@sveltejs/adapter-vercel']) {
    adapter = 'vercel';
  } else if (allDependencies['@sveltejs/adapter-node']) {
    adapter = 'node';
  } else if (allDependencies['@sveltejs/adapter-cloudflare']) {
    adapter = 'cloudflare';
  } else if (allDependencies['@sveltejs/adapter-auto']) {
    adapter = 'auto';
  }

  if (debug) {
    if (adapter === 'other') {
      // eslint-disable-next-line no-console
      console.warn(
        "[Sentry SvelteKit Plugin] Couldn't detect SvelteKit adapter. Please set the 'adapter' option manually.",
      );
    } else {
      // eslint-disable-next-line no-console
      console.log(`[Sentry SvelteKit Plugin] Detected SvelteKit ${adapter} adapter`);
    }
  }

  return adapter;
}

/**
 * Imports the package.json file and returns the parsed JSON object.
 */
async function loadPackageJson() {
  const pkgFile = path.join(process.cwd(), 'package.json');

  try {
    if (!fs.existsSync(pkgFile)) {
      throw new Error(`File ${pkgFile} doesn't exist}`);
    }

    const pkgJsonContent = (await fs.promises.readFile(pkgFile, 'utf-8')).toString();

    return JSON.parse(pkgJsonContent);
  } catch (e) {
    // eslint-disable-next-line no-console
    console.warn("[Sentry SvelteKit Plugin] Couldn't load package.json:", e);
    return undefined;
  }
}

exports.detectAdapter = detectAdapter;
//# sourceMappingURL=detectAdapter.js.map
